﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using System.Collections.ObjectModel;

namespace GroupPoints
{
    public partial class _Default : System.Web.UI.Page
    {
        Collection<Feature> selectedFeatures = new Collection<Feature>();

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                InMemoryFeatureLayer layer = new InMemoryFeatureLayer();
                layer.Columns.Add(new FeatureSourceColumn("Name", "string", 10));
               // layer.Columns.Add(new FeatureSourceColumn("Group", "string", 10));
                layer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(GeoColor.StandardColors.Blue, 10);
                layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                Feature aspen = new Feature(-119.984347, 38.929237);
                aspen.ColumnValues["Name"] = "Aspen";
                Feature wilmotMtn = new Feature(-88.181944, 42.512778);
                wilmotMtn.ColumnValues["Name"] = "WilmotMtn";
                Feature vail = new Feature(-106.362984, 39.635757);
                vail.ColumnValues["Name"] = "Vail";

                layer.InternalFeatures.Add("Aspen", aspen);
                layer.InternalFeatures.Add("WilmotMtn", wilmotMtn);
                layer.InternalFeatures.Add("Vail", vail);

                Map1.StaticOverlay.Layers.Add("citiesLayer", layer);

                Map1.CurrentExtent = Map1.StaticOverlay.GetBoundingBox();

                Session.Add("selectedFeatures", selectedFeatures);
            }
        }

        protected void Map1_Click(object sender, MapClickedEventArgs e)
        {
            Feature selectedPoint = GetSelectedPointShape(e.Position, 5);
            if (selectedPoint.Id != null)
            {
                
                selectedFeatures = (Collection<Feature>)Session["selectedFeatures"];
                if (!selectedFeatures.Contains(selectedPoint))
                {
                    selectedFeatures.Add(selectedPoint);
                    Session["selectedFeatures"] = selectedFeatures;
                    Label1.Text = "";
                    foreach (Feature selectedFeature in selectedFeatures)
                    {
                        Label1.Text += selectedFeature.ColumnValues["Name"] + " selected ";
                    }
                    
                }
            }
        }

        private Feature GetSelectedPointShape(PointShape target, float tolerenceInPixel)
        {
            InMemoryFeatureLayer citiesLayer = (InMemoryFeatureLayer)Map1.StaticOverlay.Layers["citiesLayer"];
            citiesLayer.Open();
            Collection<Feature> features = citiesLayer.FeatureSource.GetFeaturesNearestTo(target, GeographyUnit.DecimalDegree, 1, new string[]{"Name"});
            citiesLayer.Close();
            if (features.Count > 0)
            {
                Feature nearestPoint = features[0];
                float screenDistance = ExtentHelper.GetScreenDistanceBetweenTwoWorldPoints(Map1.CurrentExtent, new Feature(target), nearestPoint, (float)Map1.Width.Value, (float)Map1.Height.Value);
                if (screenDistance < tolerenceInPixel)
                {
                    return features[0];
                }
            }
            return new Feature();
        }

    }
}
